function gameplay_load()
	mousex=love.mouse.getX() --variables for tracking mouse movement
	mousey=love.mouse.getY()
	mousex_previous=love.mouse.getX()
	mousey_previous=love.mouse.getY()
	
	world:setAllowSleep(false)
	world:setCallbacks(collision_new,collision_persist,collision_end,collision_result)

	gameplay_paused=0 --pause menu stuff
	pausemenu_alpha=0
end

function gameplay_update()
	mousex_previous=mousex --track mouse movement
	mousey_previous=mousey
	mousex=love.mouse.getX() 
	mousey=love.mouse.getY()

	local a
	for a=1,objectnum-1 do
		if object[a].kind=="platform" then
			if platform_active[a]==1 and love.mouse.isDown("l") then --rotate platforms
				platform[a]:setAngularVelocity(math.rad(((mousex-mousex_previous)+(mousey-mousey_previous))/3)/love.timer.getDelta())
			else
				platform[a]:setAngularVelocity(0)
			end
			
			--limit platform rotation speed
			local rotspeedlimit=platform_size[a]/300
			if rotspeedlimit<1 then rotspeedlimit=1 end
			
			if platform[a]:getAngularVelocity()>math.rad(300/rotspeedlimit) then platform[a]:setAngularVelocity(math.rad(300/rotspeedlimit)) end
			if platform[a]:getAngularVelocity()<math.rad(-300/rotspeedlimit) then platform[a]:setAngularVelocity(math.rad(-300/rotspeedlimit)) end

			platform[a]:setX(object[a].x) --keep ball from pushing platforms
			platform[a]:setY(object[a].y)
		end

		if object[a].kind=="spring" then --spring animations
			spring_color[a]=spring_color[a]+255*love.timer.getDelta()
			if spring_color[a]>255 then spring_color[a]=255 end
		end
		
		if object[a].kind=="jet" then --jet particle systems
			if gameplay_paused==0 then
				particle_jet[a]:update(love.timer.getDelta())
			end
		end
	end
	
	local x,y=ball:getLinearVelocity()
	if x>400 then ball:setLinearVelocity(400,y) end
	if x<-400 then ball:setLinearVelocity(-400,y) end
	if y>400 then ball:setLinearVelocity(x,400) end
	if y<-400 then ball:setLinearVelocity(x,-400) end
	
	if ball:isFrozen() or ball:getX()<-16 or ball:getY()>love.graphics.getWidth()+16 then --check if ball goes off screen
		createlevel()
		gameplay_load()
	end
	
	for a=1,objectnum-1 do --cause ball to be pushed by air jets
		if object[a].kind=="jet" then
			if jet_direction[a]=="right" then
				if ball:getX()>object[a].x and ball:getY()>object[a].y-20 and ball:getY()<object[a].y+20 then
					ball:applyForce(500-(ball:getX()-object[a].x),0)
				end
				
			elseif jet_direction[a]=="left" then
				if ball:getX()<object[a].x and ball:getY()>object[a].y-20 and ball:getY()<object[a].y+20 then
					ball:applyForce(-500-(ball:getX()-object[a].x),0)
				end
				
			elseif jet_direction[a]=="up" then
				if ball:getY()<object[a].y and ball:getX()>object[a].x-20 and ball:getX()<object[a].x+20 then
					ball:applyForce(0,-500-(ball:getY()-object[a].y))
				end
			
			elseif jet_direction[a]=="down" then
				if ball:getY()>object[a].y and ball:getX()>object[a].x-20 and ball:getX()<object[a].x+20 then
					ball:applyForce(0,500-(ball:getY()-object[a].y))
				end
			end
		end
	end
	
	if gameplay_paused==0 then
		world:update(love.timer.getDelta())
	end

	if gameplay_paused==1 then --pause menu stuff
		pausemenu_alpha=pausemenu_alpha+8*love.timer.getDelta()

		if love.mouse.getY()>450 then pausemenu_selected=3
		elseif love.mouse.getY()>375 then pausemenu_selected=2
		else pausemenu_selected=1 end
	else
		pausemenu_alpha=pausemenu_alpha-8*love.timer.getDelta()
	end

	if pausemenu_alpha>.85 then pausemenu_alpha=.85 end
	if pausemenu_alpha<0 then pausemenu_alpha=0 end
end

function collision_new(first,second,contact)
	if first=="goal" and second=="ball" then --check if ball meets goal
		createlevel()
		gameplay_load()
	end
	
	if first=="ball" and second=="spike" then --check if ball hits spikes
		createlevel()
		gameplay_load()
	end

	local a --bounce ball off springs
	for a=1,objectnum-1 do
		if object[a].kind=="spring" then
			if first=="spring"..tostring(a) and second=="ball" then
				ball:applyImpulse(0,-150)
				spring_color[a]=128
			end
		end
	end
	
	local b --activate platforms when ball touches them
	for a=1,objectnum-1 do
		if first=="platform"..tostring(a) and second=="ball" then
			for b=1,objectnum-1 do
				platform_active[b]=0
			end
			platform_active[a]=1
		end
	end
end

function gameplay_draw()
	--draw physics stuff
	local a, b
	for a=1,objectnum-1 do
		if object[a].kind=="platform" then --draw platform shapes
			if platform_active[a]==1 then
				love.graphics.setColor(255,0,0,255)
			else
				love.graphics.setColor(255,255,255,255)
			end
			
			for b=1,shape_amount[a] do
				love.graphics.polygon("fill",platform_shape[a][b]:getPoints())
			end
		end
	end
	
	for a=1,objectnum-1 do --draw other stuff
		if object[a].kind=="ball" then --draw ball
			love.graphics.setColor(255,255,255,255)
			love.graphics.circle("fill",ball:getX(),ball:getY(),ball_shape:getRadius(),16)
		end
		
		if object[a].kind=="goal" then --draw goal
			love.graphics.setColor(0,255,0,255)
			love.graphics.rectangle("fill",goal:getX()-16,goal:getY()-16,32,32)
		end
		
		if object[a].kind=="wall" then --draw wall
			love.graphics.setColor(255,255,255,255)
			love.graphics.draw(image_wall,wall[a]:getX(),wall[a]:getY(),0,1,1,16,16)
		end
		
		if object[a].kind=="spike" then --draw spikeballs
			love.graphics.setColor(255,255,255,255)
			love.graphics.draw(image_spikeball,spike[a]:getX(),spike[a]:getY(),0,1,1,15,15)
		end

		if object[a].kind=="spring" then --draw springs
			love.graphics.setColor(spring_color[a],spring_color[a],255,255)
			love.graphics.draw(image_spring,spring[a]:getX(),spring[a]:getY(),0,1,1,15,15)
		end
	end
	
	for a=1,objectnum-1 do
		if object[a].kind=="jet" then --draw jet particle systems
			love.graphics.setColor(255,255,255,255)
			love.graphics.draw(particle_jet[a],object[a].x,object[a].y)
			
			for b=1,math.random(20,21) do --draw glowy circle
				love.graphics.setColor(255,255,255,255/b)
				love.graphics.circle("fill",object[a].x,object[a].y,b,b)
			end
		end
	end
		

	--draw pause menu
	love.graphics.setColor(0,0,0,255*pausemenu_alpha)
	love.graphics.rectangle("fill",0,0,love.graphics.getWidth(),love.graphics.getHeight())
	love.graphics.setFont(font_verasans20)
	love.graphics.setColor(255,255,255,255*pausemenu_alpha)
	love.graphics.printf("Paused",50,150,love.graphics.getWidth()-100,"center")

	love.graphics.setLineWidth(4)

	if pausemenu_selected==1 then --draw button backgrounds
		love.graphics.setColor(128,128,128,150*pausemenu_alpha)
	else
		love.graphics.setColor(128,128,128,100*pausemenu_alpha)
	end
	love.graphics.rectangle("fill",love.graphics.getWidth()/2-100,300,200,50)

	if pausemenu_selected==2 then
		love.graphics.setColor(128,128,128,150*pausemenu_alpha)
	else
		love.graphics.setColor(128,128,128,100*pausemenu_alpha)
	end
	love.graphics.rectangle("fill",love.graphics.getWidth()/2-100,375,200,50)

	if pausemenu_selected==3 then
		love.graphics.setColor(128,128,128,150*pausemenu_alpha)
	else
		love.graphics.setColor(128,128,128,100*pausemenu_alpha)
	end
	love.graphics.rectangle("fill",love.graphics.getWidth()/2-100,450,200,50)

	if pausemenu_selected==1 then --draw buttons
		love.graphics.setColor(255,255,255,255*pausemenu_alpha)
	else
		love.graphics.setColor(200,200,200,255*pausemenu_alpha)
	end
	love.graphics.rectangle("line",love.graphics.getWidth()/2-100,300,200,50)
	love.graphics.printf("Continue",love.graphics.getWidth()/2-80,325,160,"center")

	if pausemenu_selected==2 then
		love.graphics.setColor(255,255,255,255*pausemenu_alpha)
	else
		love.graphics.setColor(200,200,200,255*pausemenu_alpha)
	end
	love.graphics.rectangle("line",love.graphics.getWidth()/2-100,375,200,50)
	love.graphics.printf("Restart level",love.graphics.getWidth()/2-80,400,160,"center")

	if pausemenu_selected==3 then
		love.graphics.setColor(255,255,255,255*pausemenu_alpha)
	else
		love.graphics.setColor(200,200,200,255*pausemenu_alpha)
	end
	love.graphics.rectangle("line",love.graphics.getWidth()/2-100,450,200,50)
	love.graphics.printf("Quit to menu",love.graphics.getWidth()/2-80,475,160,"center")
end
